summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/combobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/combobox.h')
-rw-r--r--kalarm/lib/combobox.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kalarm/lib/combobox.h b/kalarm/lib/combobox.h
index 3f33a63d..5f8f4cc3 100644
--- a/kalarm/lib/combobox.h
+++ b/kalarm/lib/combobox.h
@@ -34,21 +34,22 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class ComboBox : public QComboBox
+class ComboBox : public TQComboBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit ComboBox(TQWidget* parent = 0, const char* name = 0);
+ explicit ComboBox(TQWidget* tqparent = 0, const char* name = 0);
/** Constructor.
* @param rw True for a read-write combo box, false for a read-only combo box.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit ComboBox(bool rw, TQWidget* parent = 0, const char* name = 0);
+ explicit ComboBox(bool rw, TQWidget* tqparent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the combo box is read-only for the user. If read-only,
@@ -34,21 +34,22 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -34,21 +34,22 @@
/** Constructor.
* @param rw True for a read-write combo box, false for a read-only combo box.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/